@@ -26,14 +26,14 @@ from __future__ import annotations
 import hashlib
 import logging
 
+from pathlib import Path
 from time import time
 from typing import TYPE_CHECKING
-from pathlib import Path
 
-from novelwriter.enum import nwItemLayout, nwItemClass
-from novelwriter.error import formatException
 from novelwriter.common import formatTimeStamp, isHandle
 from novelwriter.core.item import NWItem
+from novelwriter.enum import nwItemClass, nwItemLayout
+from novelwriter.error import formatException, logException
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.project import NWProject
@@ -52,7 +52,7 @@ class NWDocument:
 
     def __init__(self, project: NWProject, tHandle: str | None) -> None:
 
-        self._project  = project
+        self._project = project
 
         self._item      = None   # The currently open item
         self._handle    = None   # The handle of the currently open item
@@ -106,7 +106,28 @@ class NWDocument:
         return self._item
 
     ##
-    #  Class Methods
+    #  Static Methods
+    ##
+
+    @staticmethod
+    def quickReadText(content: Path, tHandle: str) -> str:
+        """Return the text of a document in a fast and efficient way."""
+        if (path := content / f"{tHandle}.nwd").is_file():
+            try:
+                with open(path, mode="r", encoding="utf-8") as inFile:
+                    line = ""
+                    for _ in range(10):
+                        if not (line := inFile.readline()).startswith(r"%%~"):
+                            break
+                    return line + inFile.read()
+            except Exception:
+                logger.error("Cannot read document with handle '%s'", tHandle)
+                logException()
+                return ""
+        return ""
+
+    ##
+    #  Methods
     ##
 
     def fileExists(self) -> bool:
@@ -155,7 +176,7 @@ class NWDocument:
             try:
                 with open(docPath, mode="r", encoding="utf-8") as inFile:
                     # Check the first <= 10 lines for metadata
-                    for i in range(10):
+                    for _ in range(10):
                         line = inFile.readline()
                         if line.startswith(r"%%~"):
                             self._parseMeta(line)
@@ -284,12 +305,12 @@ class NWDocument:
         """Parse the document meta tag and return the name, parent,
         class and layout meta values.
         """
-        theName = self._docMeta.get("name", "")
-        theParent = self._docMeta.get("parent", None)
-        theClass = self._docMeta.get("class", None)
-        theLayout = self._docMeta.get("layout", None)
+        name = self._docMeta.get("name", "")
+        parent = self._docMeta.get("parent", None)
+        itemClass = self._docMeta.get("class", None)
+        itemLayout = self._docMeta.get("layout", None)
 
-        return theName, theParent, theClass, theLayout
+        return name, parent, itemClass, itemLayout
 
     def getError(self) -> str:
         """Return the last recorded exception."""
@@ -338,5 +359,3 @@ class NWDocument:
             logger.debug("Unknown meta data: '%s'", metaLine.strip())
 
         return
-
-# END Class NWDocument
