@@ -23,17 +23,17 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import sys
-import random
 import logging
+import random
+import sys
 
 from typing import TYPE_CHECKING
 
-from PyQt5.QtGui import QFont, QFontDatabase
 from PyQt5.QtCore import Qt, pyqtSlot
+from PyQt5.QtGui import QFont, QFontDatabase
 from PyQt5.QtWidgets import (
-    QWidget, qApp, QDialog, QGridLayout, QStyle, QPlainTextEdit, QLabel,
-    QDialogButtonBox
+    QApplication, QDialog, QDialogButtonBox, QGridLayout, QLabel,
+    QPlainTextEdit, QStyle, QWidget
 )
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -42,29 +42,21 @@ if TYPE_CHECKING:  # pragma: no cover
 logger = logging.getLogger(__name__)
 
 
-# =============================================================================================== #
-#  Utility Functions
-# =============================================================================================== #
-
 def logException() -> None:
     """Log the content of an exception message."""
     exType, exValue, _ = sys.exc_info()
     if exType is not None:
-        logger.error("%s: %s", exType.__name__, str(exValue))
+        logger.error(f"{exType.__name__}: {str(exValue)}", stacklevel=2)
     return
 
 
-def formatException(exc) -> str:
+def formatException(exc: BaseException) -> str:
     """Format an exception as a string the same way the default
     exception handler does.
     """
     return f"{type(exc).__name__}: {str(exc)}"
 
 
-# =============================================================================================== #
-#  Error Handler
-# =============================================================================================== #
-
 class NWErrorMessage(QDialog):
 
     def __init__(self, parent: QWidget) -> None:
@@ -74,7 +66,9 @@ class NWErrorMessage(QDialog):
         # Widgets
         self.msgIcon = QLabel()
         self.msgIcon.setPixmap(
-            qApp.style().standardIcon(QStyle.SP_MessageBoxCritical).pixmap(64, 64)
+            QApplication.style().standardIcon(
+                QStyle.StandardPixmap.SP_MessageBoxCritical
+            ).pixmap(64, 64)
         )
         self.msgHead = QLabel()
         self.msgHead.setOpenExternalLinks(True)
@@ -88,13 +82,13 @@ class NWErrorMessage(QDialog):
         self.msgBody.setFont(font)
         self.msgBody.setReadOnly(True)
 
-        self.btnBox = QDialogButtonBox(QDialogButtonBox.Close)
+        self.btnBox = QDialogButtonBox(QDialogButtonBox.StandardButton.Close)
         self.btnBox.rejected.connect(self._doClose)
 
         # Assemble
         self.mainBox = QGridLayout()
-        self.mainBox.addWidget(self.msgIcon, 0, 0, 2, 1, Qt.AlignTop)
-        self.mainBox.addWidget(self.msgHead, 0, 1, 1, 1, Qt.AlignTop)
+        self.mainBox.addWidget(self.msgIcon, 0, 0, 2, 1, Qt.AlignmentFlag.AlignTop)
+        self.mainBox.addWidget(self.msgHead, 0, 1, 1, 1, Qt.AlignmentFlag.AlignTop)
         self.mainBox.addWidget(self.msgBody, 1, 1, 1, 1)
         self.mainBox.addWidget(self.btnBox,  2, 0, 1, 2)
         self.mainBox.setSpacing(16)
@@ -123,9 +117,11 @@ class NWErrorMessage(QDialog):
         error traceback.
         """
         from traceback import format_tb
+
+        from PyQt5.QtCore import PYQT_VERSION_STR, QT_VERSION_STR, QSysInfo
+
         from novelwriter import __version__
         from novelwriter.constants import nwConst
-        from PyQt5.QtCore import QT_VERSION_STR, PYQT_VERSION_STR, QSysInfo
 
         self.msgHead.setText(
             "<p>An unhandled error has been encountered.</p>"
@@ -173,20 +169,19 @@ class NWErrorMessage(QDialog):
         self.close()
         return
 
-# END Class NWErrorMessage
-
 
 def exceptionHandler(exType: type, exValue: BaseException, exTrace: TracebackType) -> None:
     """Function to catch unhandled global exceptions."""
     from traceback import print_tb
-    from PyQt5.QtWidgets import qApp
+
+    from PyQt5.QtWidgets import QApplication
 
     logger.critical("%s: %s", exType.__name__, str(exValue))
     print_tb(exTrace)
 
     try:
         nwGUI = None
-        for qWin in qApp.topLevelWidgets():
+        for qWin in QApplication.topLevelWidgets():
             if qWin.objectName() == "GuiMain":
                 nwGUI = qWin
                 break
@@ -197,7 +192,7 @@ def exceptionHandler(exType: type, exValue: BaseException, exTrace: TracebackTyp
 
         errMsg = NWErrorMessage(nwGUI)
         errMsg.setMessage(exType, exValue, exTrace)
-        errMsg.exec_()
+        errMsg.exec()
 
         try:
             # Try a controlled shutdown
@@ -209,7 +204,7 @@ def exceptionHandler(exType: type, exValue: BaseException, exTrace: TracebackTyp
             logger.critical("Could not close the project before exiting")
             logger.critical(formatException(exc))
 
-        qApp.exit(1)
+        QApplication.exit(1)
 
     except Exception as exc:
         logger.critical(formatException(exc))
